@@ -1,3 +1,5 @@
+from datetime import timedelta
+
 from logilab.common.date import date_range, todate, todatetime
 
 from cubicweb.interfaces import ICalendarable
@@ -72,7 +74,7 @@ class Calendar(AnyEntity):
         else:
             parent = {}
         # iterate
-        for date in date_range(start, stop):
+        for date in date_range(start, stop + timedelta(days=1)):
             key = (self.eid, date)
             value = None
             # try period
@@ -127,6 +129,7 @@ class Calendar(AnyEntity):
         """
         day_types = []
         cache = self.daytype_cache.setdefault('cal_date', {})
+        stop += timedelta(days=1) # upper bound excluded by date_range
         for date in date_range(start, stop):
             key = (self.eid, todate(date))
             if key not in cache:
